==> hubzero-submit-pegasus_4.5.2-3+deb8.tar.gz: pegasus-4.5.2/share/doc/pegasus/html/data_transfers.php <==
<?php  
            include_once( $_SERVER['DOCUMENT_ROOT']."/static/includes/common.inc.php" );
            do_html_header("Documentation");
        ?><div id="content">
<div class="navheader">
<table width="100%" summary="Navigation header"><tr>
<td width="20%" align="left">
<a accesskey="p" href="hierarchial_workflows.php">Prev</a> </td>
<td width="60%" align="center"><a accesskey="h" href="index.php">Table of Contents</a></td>
<td width="20%" align="right"> <a accesskey="n" href="job_throttling.php">Next</a>
</td>
</tr></table>
<hr>
</div>
<div class="section" title="10.5. Optimizing Data Transfers">
<div class="titlepage"><div><div><h2 class="title" style="clear: both">
<a name="data_transfers"></a>10.5. Optimizing Data Transfers</h2></div></div></div>
<p><span class="emphasis"><em>Issue:</em></span> When it comes to data transfers, Pegasus
    ships with a default configuration which is trying to strike a balance
    between performance and aggressiveness. We obviously want data transfers
    to be as quick as possibly, but we also do not want our transfers to
    overwhelm data services and systems.</p>
<p><span class="emphasis"><em>Solution:</em></span> The default configuration consists of
    a combination of the maximum number of transfer jobs per level in the
    workflow, and how many threads such a pegasus-transfer job can
    spawn.</p>
<p>Information on how to control the number of stagein and stageout
    jobs can be found in the <a class="link" href="transfer.php#data_movement_nodes" title="9.2.5. Addition of Separate Data Movement Nodes to Executable Workflow">Data Movement
    Nodes</a> section.</p>
<p>How to control the number of threads pegasus-transfer can use
    depends on if you want to control standard transfer jobs, or PegasusLite.
    For the former, see the <a class="link" href="properties.php#transfer_props" title="12.3.9. Transfer Configuration Properties">pegasus.transfer.threads</a> property, and for
    the latter the <a class="link" href="properties.php#transfer_props" title="12.3.9. Transfer Configuration Properties">pegasus.transfer.lite.threads</a>
    property.</p>
</div>
<div class="navfooter">
<hr>
<table width="100%" summary="Navigation footer">
<tr>
<td width="40%" align="left">
<a accesskey="p" href="hierarchial_workflows.php">Prev</a> </td>
<td width="20%" align="center"><a accesskey="u" href="optimization.php">Up</a></td>
<td width="40%" align="right"> <a accesskey="n" href="job_throttling.php">Next</a>
</td>
</tr>
<tr>
<td width="40%" align="left" valign="top">10.4. Hierarchical Workflows </td>
<td width="20%" align="center"><a accesskey="h" href="index.php">Table of Contents</a></td>
<td width="40%" align="right" valign="top"> 10.6. Job Throttling</td>
</tr>
</table>
</div>
</div><?php  
            do_html_footer();
        ?>

==> hubzero-submit-pegasus_4.5.2-4+deb8.tar.gz: pegasus-4.5.2/share/doc/pegasus/html/data_transfers.php <==
<?php  
            include_once( $_SERVER['DOCUMENT_ROOT']."/static/includes/common.inc.php" );
            do_html_header("Documentation");
        ?><div id="content">
<div class="navheader">
<table width="100%" summary="Navigation header"><tr>
<td width="20%" align="left">
<a accesskey="p" href="hierarchial_workflows.php">Prev</a> </td>
<td width="60%" align="center"><a accesskey="h" href="index.php">Table of Contents</a></td>
<td width="20%" align="right"> <a accesskey="n" href="job_throttling.php">Next</a>
</td>
</tr></table>
<hr>
</div>
<div class="section">
<div class="titlepage"><div><div><h2 class="title" style="clear: both">
<a name="data_transfers"></a>10.5. Optimizing Data Transfers</h2></div></div></div>
<p><span class="emphasis"><em>Issue:</em></span> When it comes to data transfers, Pegasus
    ships with a default configuration which is trying to strike a balance
    between performance and aggressiveness. We obviously want data transfers
    to be as quick as possibly, but we also do not want our transfers to
    overwhelm data services and systems.</p>
<p><span class="emphasis"><em>Solution:</em></span> The default configuration consists of
    a combination of the maximum number of transfer jobs per level in the
    workflow, and how many threads such a pegasus-transfer job can
    spawn.</p>
<p>Information on how to control the number of stagein and stageout
    jobs can be found in the <a class="link" href="transfer.php#data_movement_nodes" title="9.2.5. Addition of Separate Data Movement Nodes to Executable Workflow">Data Movement
    Nodes</a> section.</p>
<p>How to control the number of threads pegasus-transfer can use
    depends on if you want to control standard transfer jobs, or PegasusLite.
    For the former, see the <a class="link" href="properties.php#transfer_props" title="12.3.9. Transfer Configuration Properties">pegasus.transfer.threads</a> property, and for
    the latter the <a class="link" href="properties.php#transfer_props" title="12.3.9. Transfer Configuration Properties">pegasus.transfer.lite.threads</a>
    property.</p>
</div>
<div class="navfooter">
<hr>
<table width="100%" summary="Navigation footer">
<tr>
<td width="40%" align="left">
<a accesskey="p" href="hierarchial_workflows.php">Prev</a> </td>
<td width="20%" align="center"><a accesskey="u" href="optimization.php">Up</a></td>
<td width="40%" align="right"> <a accesskey="n" href="job_throttling.php">Next</a>
</td>
</tr>
<tr>
<td width="40%" align="left" valign="top">10.4. Hierarchical Workflows </td>
<td width="20%" align="center"><a accesskey="h" href="index.php">Table of Contents</a></td>
<td width="40%" align="right" valign="top"> 10.6. Job Throttling</td>
</tr>
</table>
</div>
</div><?php  
            do_html_footer();
        ?>
